==> pmml-model-gwt-1.5.12-sources.jar: org/dmg/pmml/DiscretizeBin.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.adapters.ObjectAdapter;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "DiscretizeBin", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "interval"
})
@JsonRootName("DiscretizeBin")
@JsonPropertyOrder({
    "binValue",
    "extensions",
    "interval"
})
public class DiscretizeBin
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<DiscretizeBin>
{

    @XmlAttribute(name = "binValue", required = true)
    @XmlJavaTypeAdapter(ObjectAdapter.class)
    @XmlSchemaType(name = "anySimpleType")
    @JsonProperty("binValue")
    private Object binValue;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "Interval", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("Interval")
    private Interval interval;
    private final static long serialVersionUID = 67371267L;

    public DiscretizeBin() {
    }

    @ValueConstructor
    public DiscretizeBin(
        @org.jpmml.model.annotations.Property("binValue")
        Object binValue,
        @org.jpmml.model.annotations.Property("interval")
        Interval interval) {
        this.binValue = binValue;
        this.interval = interval;
    }

    public Object getBinValue() {
        return binValue;
    }

    public DiscretizeBin setBinValue(
        @org.jpmml.model.annotations.Property("binValue")
        Object binValue) {
        this.binValue = binValue;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public DiscretizeBin addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public Interval getInterval() {
        return interval;
    }

    public DiscretizeBin setInterval(
        @org.jpmml.model.annotations.Property("interval")
        Interval interval) {
        this.interval = interval;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getInterval());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.0-sources.jar: org/dmg/pmml/DiscretizeBin.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.ObjectAdapter;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "DiscretizeBin", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "interval"
})
@JsonRootName("DiscretizeBin")
@JsonPropertyOrder({
    "binValue",
    "extensions",
    "interval"
})
public class DiscretizeBin
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<DiscretizeBin>
{

    @XmlAttribute(name = "binValue", required = true)
    @XmlJavaTypeAdapter(ObjectAdapter.class)
    @XmlSchemaType(name = "anySimpleType")
    @JsonProperty("binValue")
    private Object binValue;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "Interval", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("Interval")
    private Interval interval;
    private final static long serialVersionUID = 67371269L;

    public DiscretizeBin() {
    }

    @ValueConstructor
    public DiscretizeBin(
        @org.jpmml.model.annotations.Property("binValue")
        Object binValue,
        @org.jpmml.model.annotations.Property("interval")
        Interval interval) {
        this.binValue = binValue;
        this.interval = interval;
    }

    public Object getBinValue() {
        return binValue;
    }

    public DiscretizeBin setBinValue(
        @org.jpmml.model.annotations.Property("binValue")
        Object binValue) {
        this.binValue = binValue;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public DiscretizeBin addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public Interval getInterval() {
        return interval;
    }

    public DiscretizeBin setInterval(
        @org.jpmml.model.annotations.Property("interval")
        Interval interval) {
        this.interval = interval;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getInterval());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
